@@ -1,5 +1,5 @@
 package Mojolicious::Plugin::Yancy;
-our $VERSION = '1.018';
+our $VERSION = '1.019';
 # ABSTRACT: Embed a simple admin CMS into your Mojolicious application
 
 #pod =head1 SYNOPSIS
@@ -400,7 +400,9 @@ use Mojo::Base 'Mojolicious::Plugin';
 use Yancy;
 use Mojo::JSON qw( true false );
 use Mojo::File qw( path );
+use Mojo::JSON qw( decode_json );
 use Mojo::Loader qw( load_class );
+use Mojo::Util qw( url_escape );
 use Sys::Hostname qw( hostname );
 use Yancy::Util qw( load_backend curry );
 use JSON::Validator::OpenAPI;
@@ -412,6 +414,7 @@ sub register {
     my $route = $config->{route} // $app->routes->any( '/yancy' );
     $route->to( return_to => $config->{return_to} // '/' );
     $config->{api_controller} //= 'Yancy::API';
+    $config->{openapi} = _ensure_json_data( $app, $config->{openapi} );
 
     # Resources and templates
     my $share = path( __FILE__ )->sibling( 'Yancy' )->child( 'resources' );
@@ -508,6 +511,15 @@ sub register {
     $formats->{ tel } = sub { 1 };
 }
 
+# if false or a ref, just returns same
+# if non-ref, treat as JSON-containing file, load and decode
+sub _ensure_json_data {
+    my ( $app, $data ) = @_;
+    return $data if !$data or ref $data;
+    # assume a file in JSON format: load and parse it
+    decode_json $app->home->child( $data )->slurp;
+}
+
 # mutates $spec
 sub _openapi_spec_add_mojo {
     my ( $self, $spec, $config ) = @_;
@@ -606,9 +618,9 @@ sub _openapi_spec_from_schema {
         $paths{ '/' . $name } = {
             get => {
                 parameters => [
-                    { '$ref' => '#/parameters/$limit' },
-                    { '$ref' => '#/parameters/$offset' },
-                    { '$ref' => '#/parameters/$order_by' },
+                    { '$ref' => '#/parameters/%24limit' },
+                    { '$ref' => '#/parameters/%24offset' },
+                    { '$ref' => '#/parameters/%24order_by' },
                     map {; {
                         name => $_,
                         in => 'query',
@@ -631,7 +643,7 @@ sub _openapi_spec_from_schema {
                                 items => {
                                     type => 'array',
                                     description => 'This page of items',
-                                    items => { '$ref' => "#/definitions/${name}" },
+                                    items => { '$ref' => "#/definitions/" . url_escape $name },
                                 },
                             },
                         },
@@ -648,13 +660,16 @@ sub _openapi_spec_from_schema {
                         name => "newItem",
                         in => "body",
                         required => true,
-                        schema => { '$ref' => "#/definitions/${name}" },
+                        schema => { '$ref' => "#/definitions/" . url_escape $name },
                     },
                 ],
                 responses => {
                     201 => {
                         description => "Entry was created",
-                        schema => { '$ref' => "#/definitions/${name}/properties/${id_field}" },
+                        schema => {
+                            '$ref' => sprintf "#/definitions/%s/properties/%s",
+                                      map { url_escape $_ } $name, $id_field,
+                        },
                     },
                     default => {
                         description => "Unexpected error",
@@ -681,7 +696,7 @@ sub _openapi_spec_from_schema {
                 responses => {
                     200 => {
                         description => "Item details",
-                        schema => { '$ref' => "#/definitions/${name}" },
+                        schema => { '$ref' => "#/definitions/" . url_escape $name },
                     },
                     default => {
                         description => "Unexpected error",
@@ -697,13 +712,13 @@ sub _openapi_spec_from_schema {
                         name => "newItem",
                         in => "body",
                         required => true,
-                        schema => { '$ref' => "#/definitions/${name}" },
+                        schema => { '$ref' => "#/definitions/" . url_escape $name },
                     }
                 ],
                 responses => {
                     200 => {
                         description => "Item was updated",
-                        schema => { '$ref' => "#/definitions/${name}" },
+                        schema => { '$ref' => "#/definitions/" . url_escape $name },
                     },
                     default => {
                         description => "Unexpected error",
@@ -998,7 +1013,7 @@ Mojolicious::Plugin::Yancy - Embed a simple admin CMS into your Mojolicious appl
 
 =head1 VERSION
 
-version 1.018
+version 1.019
 
 =head1 SYNOPSIS
 
