@@ -339,6 +339,24 @@ var app = new Vue({
                         // example the `x-id-field` is "name" or "username"
                         return !seen[x]++ && definition.properties[x];
                     } );
+                    // Show a warning to the user if we think this
+                    // guessed value for x-list-columns is kind of
+                    // useless (a non-string field is probably not
+                    // useful as a human identifier)
+                    // XXX: We could write better heuristics for
+                    // listable columns by finding the first 5-6 columns
+                    // (by x-order) that aren't textarea strings or
+                    // markdown strings.
+                    // Or, we could add CSS to prevent long strings from
+                    // breaking the table ("white-space: nowrap;
+                    // text-overflow: ellipsis" would show only the
+                    // first part of the first line of a large block of
+                    // text.
+                    if ( definition[ 'x-list-columns' ].length == 1
+                        && definition.properties[ definition[ 'x-list-columns' ][0] ].type != 'string'
+                    ) {
+                        definition[ 'x-list-columns-guessed' ] = true;
+                    }
                 }
 
                 for ( var propKey in definition.properties ) {
